@@ -1,7 +1,7 @@
 /*
 * libslack - http://libslack.org/
 *
-* Copyright (C) 1999-2004 raf <raf@raf.org>
+* Copyright (C) 1999-2010 raf <raf@raf.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * or visit http://www.gnu.org/copyleft/gpl.html
 *
-* 20040806 raf <raf@raf.org>
+* 20100612 raf <raf@raf.org>
 */
 
 /*
@@ -855,15 +855,15 @@ Close all file descriptors:
 
 =head1 SEE ALSO
 
-L<libslack(3)|libslack(3)>,
-L<sysconf(2)|sysconf(2)>,
-L<pathconf(2)|pathconf(2)>,
-L<fpathconf(2)|fpathconf(2)>,
-L<locker(3)|locker(3)>
+I<libslack(3)>,
+I<sysconf(2)>,
+I<pathconf(2)>,
+I<fpathconf(2)>,
+I<locker(3)>
 
 =head1 AUTHOR
 
-20040806 raf <raf@raf.org>
+20100612 raf <raf@raf.org>
 
 =cut
 
