@@ -1,7 +1,7 @@
 /*
 * libslack - http://libslack.org/
 *
-* Copyright (C) 1999-2004 raf <raf@raf.org>
+* Copyright (C) 1999-2010 raf <raf@raf.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * or visit http://www.gnu.org/copyleft/gpl.html
 *
-* 20040806 raf <raf@raf.org>
+* 20100612 raf <raf@raf.org>
 */
 
 #ifndef LIBSLACK_STD_H
@@ -44,13 +44,13 @@
 
 #ifndef NO_POSIX_C_SOURCE
 #ifndef _POSIX_C_SOURCE
-#define _POSIX_C_SOURCE 199506L
+#define _POSIX_C_SOURCE 200809
 #endif
 #endif
 
 #ifndef NO_XOPEN_SOURCE
 #ifndef _XOPEN_SOURCE
-#define _XOPEN_SOURCE 500
+#define _XOPEN_SOURCE 700
 #endif
 #endif
 
