@@ -1,7 +1,7 @@
 /*
 * libslack - http://libslack.org/
 *
-* Copyright (C) 1999-2004 raf <raf@raf.org>
+* Copyright (C) 1999-2010 raf <raf@raf.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * or visit http://www.gnu.org/copyleft/gpl.html
 *
-* 20040806 raf <raf@raf.org>
+* 20100612 raf <raf@raf.org>
 */
 
 /*
@@ -58,7 +58,7 @@ C<format> may not be a multibyte character string; and
 
 Scanning a pointer (C<"%p">) may not exactly match the format that your
 I<printf(3)> uses to print pointers on your system. This version accepts
-pointers as a hexadecimal number with or without a preceeding C<0x>.
+pointers as a hexadecimal number with or without a preceding C<0x>.
 
 =back
 
@@ -68,7 +68,7 @@ MT-Safe if and only if no thread calls I<setlocale(3)>. Since locales are
 inherently non-threadsafe as they are currently defined, this shouldn't be a
 problem. Just call C<setlocale(LC_ALL, "")> once after program
 initialisation and never again (at least not after creating any threads). If
-it is a problem, just change C<localeconv()->decimal_point[0]> in the source
+it is a problem, just change C<localeconv()-E<gt>decimal_point[0]> in the source
 to C<'.'> and it will be MT-Safe at the expense of losing locale support.
 
 =head1 EXAMPLE
@@ -116,7 +116,7 @@ I<gcc(1)> warns that:
 
 However, the ANSI C standard (Section 7.9.6.2) states that:
 
-"Finally, the conversion specifiers C<e>, C<f>, and C<g> shall be preceeded
+"Finally, the conversion specifiers C<e>, C<f>, and C<g> shall be preceded
 by C<l> if the corresponding argument is a pointer to I<double> rather than
 a pointer to C<float>, or by C<L> if it is a pointer to I<long double>."
 
@@ -126,12 +126,12 @@ I<vsscanf(3)>, just ignore them.
 
 =head1 SEE ALSO
 
-L<libslack(3)|libslack(3)>,
-L<sscanf(3)|sscanf(3)>
+I<libslack(3)>,
+I<sscanf(3)>
 
 =head1 AUTHOR
 
-20040806 raf <raf@raf.org>
+20100612 raf <raf@raf.org>
 
 =cut
 
